macro_rules! pm_init {
() => { ... };
}Expand description
use this in final bin crate, this will include pm_bin.rs, which provide print_version function
macro_rules! pm_init {
() => { ... };
}use this in final bin crate, this will include pm_bin.rs, which provide print_version function